@@ -3,6 +3,7 @@ Interact with GitHub Pull Requests.
 """
 
 
+# pylint: disable=too-many-arguments
 class Pulls:
     # pylint: disable=too-many-public-methods
     """
@@ -16,7 +17,7 @@ class Pulls:
         self._base_url = client._base_url
         self._execute = client._execute
 
-    def list_pull_requests(self, owner, repo, payload=None):
+    def list_pull_requests(self, owner, repo, params=None, payload=None):
         """
         List pull requests
         https://docs.github.com/rest/reference/pulls#list-pull-requests
@@ -34,10 +35,10 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_pull_request(self, owner, repo, payload=None):
+    def create_a_pull_request(self, owner, repo, params=None, payload=None):
         """
         Create a pull request
         https://docs.github.com/rest/reference/pulls#create-a-pull-request
@@ -49,10 +50,10 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def list_review_comments_in_a_repository(self, owner, repo, payload=None):
+    def list_review_comments_in_a_repository(self, owner, repo, params=None, payload=None):
         """
         List review comments in a repository
         https://docs.github.com/rest/reference/pulls#list-review-comments-in-a-repository
@@ -68,10 +69,12 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def get_a_review_comment_for_a_pull_request(self, owner, repo, comment_id, payload=None):
+    def get_a_review_comment_for_a_pull_request(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         Get a review comment for a pull request
         https://docs.github.com/rest/reference/pulls#get-a-review-comment-for-a-pull-request
@@ -84,10 +87,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_a_review_comment_for_a_pull_request(self, owner, repo, comment_id, payload=None):
+    def update_a_review_comment_for_a_pull_request(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         Update a review comment for a pull request
         https://docs.github.com/rest/reference/pulls#update-a-review-comment-for-a-pull-request
@@ -100,10 +105,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def delete_a_review_comment_for_a_pull_request(self, owner, repo, comment_id, payload=None):
+    def delete_a_review_comment_for_a_pull_request(
+        self, owner, repo, comment_id, params=None, payload=None
+    ):
         """
         Delete a review comment for a pull request
         https://docs.github.com/rest/reference/pulls#delete-a-review-comment-for-a-pull-request
@@ -116,10 +123,10 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def get_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def get_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
         Get a pull request
         https://docs.github.com/rest/reference/pulls#get-a-pull-request
@@ -132,10 +139,10 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def update_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def update_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
         Update a pull request
         https://docs.github.com/rest/reference/pulls/#update-a-pull-request
@@ -148,10 +155,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}"
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
-    def list_review_comments_on_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def list_review_comments_on_a_pull_request(
+        self, owner, repo, pull_number, params=None, payload=None
+    ):
         """
         List review comments on a pull request
         https://docs.github.com/rest/reference/pulls#list-review-comments-on-a-pull-request
@@ -168,10 +177,12 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_review_comment_for_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def create_a_review_comment_for_a_pull_request(
+        self, owner, repo, pull_number, params=None, payload=None
+    ):
         """
         Create a review comment for a pull request
         https://docs.github.com/rest/reference/pulls#create-a-review-comment-for-a-pull-request
@@ -184,12 +195,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def create_a_reply_for_a_review_comment(
-        self, owner, repo, pull_number, comment_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, comment_id, params=None, payload=None
+    ):
         """
         Create a reply for a review comment
         https://docs.github.com/rest/reference/pulls#create-a-reply-for-a-review-comment
@@ -206,10 +217,10 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/comments/{comment_id}/replies"
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
-    def list_commits_on_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def list_commits_on_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
         List commits on a pull request
         https://docs.github.com/rest/reference/pulls#list-commits-on-a-pull-request
@@ -223,10 +234,10 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/commits"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def list_pull_requests_files(self, owner, repo, pull_number, payload=None):
+    def list_pull_requests_files(self, owner, repo, pull_number, params=None, payload=None):
         """
         List pull requests files
         https://docs.github.com/rest/reference/pulls#list-pull-requests-files
@@ -240,10 +251,12 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/files"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def check_if_a_pull_request_has_been_merged(self, owner, repo, pull_number, payload=None):
+    def check_if_a_pull_request_has_been_merged(
+        self, owner, repo, pull_number, params=None, payload=None
+    ):
         """
         Check if a pull request has been merged
         https://docs.github.com/rest/reference/pulls#check-if-a-pull-request-has-been-merged
@@ -256,10 +269,10 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/merge"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def merge_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def merge_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
         Merge a pull request
         https://docs.github.com/rest/reference/pulls#merge-a-pull-request
@@ -272,10 +285,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/merge"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
-    def list_requested_reviewers_for_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def list_requested_reviewers_for_a_pull_request(
+        self, owner, repo, pull_number, params=None, payload=None
+    ):
         """
         List requested reviewers for a pull request
         https://docs.github.com/rest/reference/pulls#list-requested-reviewers-for-a-pull-request
@@ -289,10 +304,12 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def request_reviewers_for_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def request_reviewers_for_a_pull_request(
+        self, owner, repo, pull_number, params=None, payload=None
+    ):
         """
         Request reviewers for a pull request
         https://docs.github.com/rest/reference/pulls#request-reviewers-for-a-pull-request
@@ -305,11 +322,11 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def remove_requested_reviewers_from_a_pull_request(
-        self, owner, repo, pull_number, payload=None
+        self, owner, repo, pull_number, params=None, payload=None
     ):
         """
         Remove requested reviewers from a pull request
@@ -323,10 +340,10 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/requested_reviewers"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reviews_for_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def list_reviews_for_a_pull_request(self, owner, repo, pull_number, params=None, payload=None):
         """
         List reviews for a pull request
         https://docs.github.com/rest/reference/pulls#list-reviews-for-a-pull-request
@@ -340,10 +357,12 @@ class Pulls:
          page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
-    def create_a_review_for_a_pull_request(self, owner, repo, pull_number, payload=None):
+    def create_a_review_for_a_pull_request(
+        self, owner, repo, pull_number, params=None, payload=None
+    ):
         """
         Create a review for a pull request
         https://docs.github.com/rest/reference/pulls#create-a-review-for-a-pull-request
@@ -356,12 +375,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews"
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def get_a_review_for_a_pull_request(
-        self, owner, repo, pull_number, review_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, review_id, params=None, payload=None
+    ):
         """
         Get a review for a pull request
         https://docs.github.com/rest/reference/pulls#get-a-review-for-a-pull-request
@@ -375,12 +394,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def update_a_review_for_a_pull_request(
-        self, owner, repo, pull_number, review_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, review_id, params=None, payload=None
+    ):
         """
         Update a review for a pull request
         https://docs.github.com/rest/reference/pulls#update-a-review-for-a-pull-request
@@ -394,12 +413,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def delete_a_pending_review_for_a_pull_request(
-        self, owner, repo, pull_number, review_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, review_id, params=None, payload=None
+    ):
         """
         Delete a pending review for a pull request
         https://docs.github.com/rest/reference/pulls#delete-a-pending-review-for-a-pull-request
@@ -413,12 +432,12 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}"
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
     def list_comments_for_a_pull_request_review(
-        self, owner, repo, pull_number, review_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, review_id, params=None, payload=None
+    ):
         """
         List comments for a pull request review
         https://docs.github.com/rest/reference/pulls#list-comments-for-a-pull-request-review
@@ -436,12 +455,12 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/comments"
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def dismiss_a_review_for_a_pull_request(
-        self, owner, repo, pull_number, review_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, review_id, params=None, payload=None
+    ):
         """
         Dismiss a review for a pull request
         https://docs.github.com/rest/reference/pulls#dismiss-a-review-for-a-pull-request
@@ -458,12 +477,12 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/dismissals"
         )
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
 
     def submit_a_review_for_a_pull_request(
-        self, owner, repo, pull_number, review_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, review_id, params=None, payload=None
+    ):
         """
         Submit a review for a pull request
         https://docs.github.com/rest/reference/pulls#submit-a-review-for-a-pull-request
@@ -479,12 +498,12 @@ class Pulls:
         url = (
             self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/reviews/{review_id}/events"
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def list_comments_in_a_pull_request_thread(
-        self, owner, repo, pull_number, thread_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, thread_id, params=None, payload=None
+    ):
         """
         List comments in a pull request thread
         https://docs.github.com/rest/reference/pulls#list-thread-comments-in-a-thread
@@ -502,12 +521,12 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments"
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, payload=None
-    ):  # pylint: disable=too-many-arguments
+        self, owner, repo, pull_number, thread_id, params=None, payload=None
+    ):
         """
         Create a pull request thread comment
         https://docs.github.com/rest/reference/pulls#create-a-thread-comment
@@ -524,13 +543,13 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments"
         )
-        response = self._execute("post", url, payload)
+        response = self._execute("post", url, params=params, payload=payload)
         return response
 
     def get_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, payload=None
+        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Get a pull request thread comment
         https://docs.github.com/rest/reference/pulls#get-a-thread-comment
@@ -548,13 +567,13 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
         )
-        response = self._execute("get", url, payload)
+        response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def update_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, payload=None
+        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Update a pull request thread comment
         https://docs.github.com/rest/reference/pulls#update-a-thread-comment
@@ -572,13 +591,13 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
         )
-        response = self._execute("patch", url, payload)
+        response = self._execute("patch", url, params=params, payload=payload)
         return response
 
     def delete_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, payload=None
+        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
     ):
-        # pylint: disable=too-many-arguments
+
         """
         Delete a pull request thread comment
         https://docs.github.com/rest/reference/pulls#delete-a-thread-comment
@@ -596,10 +615,10 @@ class Pulls:
             self._base_url
             + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}"
         )
-        response = self._execute("delete", url, payload)
+        response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def update_a_pull_request_branch(self, owner, repo, pull_number, payload=None):
+    def update_a_pull_request_branch(self, owner, repo, pull_number, params=None, payload=None):
         """
         Update a pull request branch
         https://docs.github.com/rest/reference/pulls#update-a-pull-request-branch
@@ -612,5 +631,5 @@ class Pulls:
 
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/{pull_number}/update-branch"
-        response = self._execute("put", url, payload)
+        response = self._execute("put", url, params=params, payload=payload)
         return response
